package ccc

import javax.swing.tree.TreeSelectionModel
import javax.swing.event.ListSelectionListener
import javax.swing.ListSelectionModel
import javax.swing.SwingConstants

build(CCCActions)

application(title: 'CamelCaseCon 2011',
        preferredSize: [1024, 768],
        pack: true,
        location: [50, 50],
        locationByPlatform: true,
        iconImage: imageIcon('/griffon-icon-48x48.png').image,
        iconImages: [imageIcon('/griffon-icon-48x48.png').image,
                imageIcon('/griffon-icon-32x32.png').image,
                imageIcon('/griffon-icon-16x16.png').image]) {
    panel {
        borderLayout()
        toolBar(constraints: NORTH) {
            button(action: openAction)
            button(action: detailsAction)
        }
        splitPane(dividerLocation: 200, oneTouchExpandable: true) {
            scrollPane(minimumSize: [150, 0]) {
                tree(id: 'folders', model: new FolderModel(new File('/')), valueChanged: controller.&folderChanged) {
                    cellRenderer {
                        onRender { children[0].text = value.name }
                    }
                }
                folders.selectionModel.selectionMode = TreeSelectionModel.SINGLE_TREE_SELECTION
            }
            scrollPane {
                table(id: 'content') {
                    tableModel(list: model.currentFile ? model.currentFile.listFiles() : []) {
                        propertyColumn(header: "Name", propertyName: "name", editable: false)
                        closureColumn(header: "Size", read: {it.length() < 1024 ? "${it.length()} B" : "${((int) it.length() / 1024)} kB"})
                    }
                    content.selectionModel.selectionMode = ListSelectionModel.SINGLE_SELECTION
                    content.selectionModel.addListSelectionListener({evt ->
                        if(!evt.isAdjusting) {
                            model.selectedFile = content.selectedRow >= 0 ? content.model.rows[content.selectedRow] : null
                            edt {
                                lblSelectedFile.text = model.selectedFile
                            }
                        }
                    } as ListSelectionListener)
                }
            }
        }
        panel(constraints: SOUTH) {
            borderLayout()
            label(text: bind(source: model, sourceProperty: 'currentFile'), constraints: WEST)
            label(id: 'lblSelectedFile', horizontalAlignment: SwingConstants.TRAILING, constraints: CENTER)
        }
    }
}
